![StoryLines logo](https://raw.githubusercontent.com/janberges/StoryLines/master/logo/logo.svg)

Line plots with Python and TikZ

    python3 example.py
    pdflatex example.tex

## Installation

Using a virtual environment:

    python3 -m venv venv
    source venv/bin/activate
    python3 -m pip install --upgrade pip setuptools wheel

Either from GitHub:

    python3 -m pip install git+https://github.com/janberges/StoryLines

Or from PyPI:

    python3 -m pip install storylines
